using System;
using System.Collections.Generic;
using Autofac;
using FitConnect;
using FitConnect.Exceptions;
using FitConnect.Interfaces;
using FluentAssertions;
using NUnit.Framework;

namespace BasicUnitTest;

[TestFixture]
public class SubscriberTests {

    IFitConnectSettings _settings = null!;

    [SetUp]
    public void Setup() {
        var container = MockContainer.Container.Create();
        _settings = container.Resolve<IFitConnectSettings>();
    }

    [Test]
    public void CreateSubscriber_ShouldPass() {
        // Arrange
        var clientId = Guid.NewGuid().ToString();
        var clientSecret = "VerySecret";
        var privateDecryptionKeys =  _settings.PrivateDecryptionKeys;
        var publicKey = _settings.PrivateSigningKey;

        // Act
        var subscriber = FitConnect.ClientFactory.GetSubscriberClient(FitConnectEnvironment.Test,
            clientId, clientSecret, privateDecryptionKeys, publicKey);

        // Assert
        subscriber.Should().NotBeNull();
    }

    [Test]
    public void CreateSubscriber_InvalidKeys_ShouldFail() {
        // Arrange
        var clientId = Guid.NewGuid().ToString();
        var clientSecret = "VerySecret";
        var privateDecryptionKeys = new List<string>() { "C:\\temp.key" };
        var publicKey = "C:\\temp.key";

        // Act & Assert
        var exception = Assert.Throws<FitConnectInitialisationException>(() => {
            var subscriber = FitConnect.ClientFactory.GetSubscriberClient(FitConnectEnvironment.Test,
                clientId, clientSecret, privateDecryptionKeys, publicKey);
        });

        Console.WriteLine(exception?.Message);
    }
}
